==> android-4.0.1.2-sources.jar: android/widget/QuickContactBadge.java <==
package android.widget;
public class QuickContactBadge
  extends android.widget.ImageView
  implements android.view.View.OnClickListener
{
public  QuickContactBadge(android.content.Context context) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
public  QuickContactBadge(android.content.Context context, android.util.AttributeSet attrs) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
public  QuickContactBadge(android.content.Context context, android.util.AttributeSet attrs, int defStyle) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
protected  void drawableStateChanged() { throw new RuntimeException("Stub!"); }
public  void setMode(int size) { throw new RuntimeException("Stub!"); }
protected  void onDraw(android.graphics.Canvas canvas) { throw new RuntimeException("Stub!"); }
public  void setImageToDefault() { throw new RuntimeException("Stub!"); }
public  void assignContactUri(android.net.Uri contactUri) { throw new RuntimeException("Stub!"); }
public  void assignContactFromEmail(java.lang.String emailAddress, boolean lazyLookup) { throw new RuntimeException("Stub!"); }
public  void assignContactFromPhone(java.lang.String phoneNumber, boolean lazyLookup) { throw new RuntimeException("Stub!"); }
public  void onClick(android.view.View v) { throw new RuntimeException("Stub!"); }
public  void setExcludeMimes(java.lang.String[] excludeMimes) { throw new RuntimeException("Stub!"); }
protected java.lang.String[] mExcludeMimes = null;
}

==> android-4.1.1.4-sources.jar: android/widget/QuickContactBadge.java <==
package android.widget;
public class QuickContactBadge
  extends android.widget.ImageView
  implements android.view.View.OnClickListener
{
public  QuickContactBadge(android.content.Context context) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
public  QuickContactBadge(android.content.Context context, android.util.AttributeSet attrs) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
public  QuickContactBadge(android.content.Context context, android.util.AttributeSet attrs, int defStyle) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
protected  void drawableStateChanged() { throw new RuntimeException("Stub!"); }
@java.lang.SuppressWarnings(value={"unused"})
public  void setMode(int size) { throw new RuntimeException("Stub!"); }
protected  void onDraw(android.graphics.Canvas canvas) { throw new RuntimeException("Stub!"); }
public  void setImageToDefault() { throw new RuntimeException("Stub!"); }
public  void assignContactUri(android.net.Uri contactUri) { throw new RuntimeException("Stub!"); }
public  void assignContactFromEmail(java.lang.String emailAddress, boolean lazyLookup) { throw new RuntimeException("Stub!"); }
public  void assignContactFromPhone(java.lang.String phoneNumber, boolean lazyLookup) { throw new RuntimeException("Stub!"); }
public  void onClick(android.view.View v) { throw new RuntimeException("Stub!"); }
public  void onInitializeAccessibilityEvent(android.view.accessibility.AccessibilityEvent event) { throw new RuntimeException("Stub!"); }
public  void onInitializeAccessibilityNodeInfo(android.view.accessibility.AccessibilityNodeInfo info) { throw new RuntimeException("Stub!"); }
public  void setExcludeMimes(java.lang.String[] excludeMimes) { throw new RuntimeException("Stub!"); }
protected java.lang.String[] mExcludeMimes = null;
}
